
## CATO-CLI - query.groups.whereUsed:
[Click here](https://api.catonetworks.com/documentation/#query-query.groups.whereUsed) for documentation on this operation.

### Usage for query.groups.whereUsed:

```bash
catocli query groups whereUsed -h

catocli query groups whereUsed <json>

catocli query groups whereUsed --json-file query.groups.whereUsed.json

catocli query groups whereUsed '{"groupRefInput":{"by":"ID","input":"string"}}'

catocli query groups whereUsed '{
    "groupRefInput": {
        "by": "ID",
        "input": "string"
    }
}'
```

#### Operation Arguments for query.groups.whereUsed ####

`accountId` [ID] - (required) N/A    
`groupRefInput` [GroupRefInput] - (required) N/A    
